CREATE TABLE address (
  id int NOT NULL , 
  AddressLine1 varchar (50) NOT NULL , 
  AddressLine2 varchar (50) NULL , 
  City varchar (25) NOT NULL , 
  State varchar (2) NOT NULL , 
  ZipCode varchar (10) NOT NULL 
); 

CREATE TABLE auction (
  id int NOT NULL , 
  Name varchar (30) NOT NULL , 
  Description varchar (100) NULL , 
  Status varchar (15) NULL , 
  StartingBid numeric (19,4) NULL , 
  MinBidIncrement numeric (19,4) NULL , 
  ReserveAmount numeric (19,4) NULL , 
  StartDate datetime NULL , 
  ScheduledEndDate datetime NULL , 
  ActualEndDate datetime NULL , 
  ItemId int NULL , 
  Quantity int NULL , 
  LeadingBidId int NULL , 
  WinningBidId int NULL 
); 

CREATE TABLE bid (
  id int NOT NULL , 
  TransactionId varchar (15) NOT NULL , 
  BidDateTime datetime NOT NULL , 
  Amount numeric (19,4) NOT NULL , 
  AuctionId int NOT NULL , 
  BidderId int NOT NULL 
); 

CREATE TABLE bidder (
  id int NOT NULL , 
  FirstName varchar (20) NOT NULL , 
  LastName varchar (40) NOT NULL , 
  EmailAddress varchar (50) NULL , 
  UserName varchar (15) NOT NULL , 
  Password varchar (15) NOT NULL , 
  BillingAddressId int NULL , 
  ShippingAddressId int NULL 
); 

CREATE TABLE item (
  id int NOT NULL , 
  Name varchar (50) NOT NULL , 
  Description varchar (100) NULL , 
  ImageURL varchar (100) NULL 
); 

ALTER TABLE address ADD CONSTRAINT PK_address PRIMARY KEY (id); 

ALTER TABLE auction ADD CONSTRAINT PK_auction PRIMARY KEY (id); 

ALTER TABLE bid ADD CONSTRAINT PK_bid PRIMARY KEY (id); 

ALTER TABLE bidder ADD CONSTRAINT PK_bidder PRIMARY KEY (id); 

ALTER TABLE item ADD CONSTRAINT PK_item PRIMARY KEY (id); 

ALTER TABLE auction ADD CONSTRAINT FK_auction_item FOREIGN KEY (ItemId) 
  REFERENCES item (id); 

ALTER TABLE auction ADD CONSTRAINT FK_auction_leadbid FOREIGN KEY 
  (LeadingBidId) 
  REFERENCES bid (id); 

ALTER TABLE auction ADD CONSTRAINT FK_auction_winbid FOREIGN KEY (WinningBidId) 
  REFERENCES bid (id); 

ALTER TABLE bid ADD CONSTRAINT FK_bid_auction FOREIGN KEY (AuctionId) 
  REFERENCES auction (id); 

ALTER TABLE bid ADD CONSTRAINT FK_bid_bidder FOREIGN KEY (BidderId) 
  REFERENCES bidder (id); 

ALTER TABLE bidder ADD CONSTRAINT FK_bidder_billaddress 
  FOREIGN KEY (BillingAddressId) REFERENCES address (id); 

ALTER TABLE bidder ADD CONSTRAINT FK_bidder_shipaddress 
  FOREIGN KEY (ShippingAddressId) REFERENCES address (id);